@@ -1,12 +1,11 @@
 package Monitoring::Icinga2::Client::Simple;
-$Monitoring::Icinga2::Client::Simple::VERSION = '0.001000_01'; # TRIAL
+$Monitoring::Icinga2::Client::Simple::VERSION = '0.001000_02'; # TRIAL
 
-$Monitoring::Icinga2::Client::Simple::VERSION = '0.00100001';use strict;
+$Monitoring::Icinga2::Client::Simple::VERSION = '0.00100002';use strict;
 use warnings;
 use 5.010_001;
 use Monitoring::Icinga2::Client::REST 2;
 use parent -norequire, 'Monitoring::Icinga2::Client::REST';
-use POSIX ();
 use Carp;
 use List::Util qw/ all any first /;
 use constant DEBUG => $ENV{DEBUG};
@@ -34,7 +33,7 @@ sub schedule_downtime {
     my ($self, %args) = @_;
     _checkargs(\%args, qw/ start_time end_time comment host /);
     # uncoverable condition false
-    $args{author} //= POSIX::cuserid();
+    $args{author} //= getlogin;
 
     if( $args{service} and not $args{services} ) {
         return [ $self->_schedule_downtime_type( 'Service', \%args) ];
@@ -111,7 +110,7 @@ sub send_custom_notification {
             filter => "$obj_type.name==\"$args{$obj_type}\"",
             comment => $args{comment},
             # uncoverable condition false
-            author => $args{author} // POSIX::cuserid(),
+            author => $args{author} // getlogin,
         }
     );
 }
@@ -254,7 +253,7 @@ Monitoring::Icinga2::Client::Simple
 
 =head1 VERSION
 
-version 0.001000_01
+version 0.001000_02
 
 =head1 DESCRIPTION
 
@@ -370,7 +369,7 @@ C<services>: set to a true value to set downtimes on all of a host's services. D
 
 =item *
 
-C<author>: will use L<POSIX/cuserid> if unset
+C<author>: will use L<getlogin> if unset
 
 =item *
 
